package cn.superdesk.sync2es.handler;

import cn.superdesk.canal.client.annotation.CanalTable;
import cn.superdesk.canal.client.handler.EntryHandler;
import cn.superdesk.sync2es.entity.es.GoodsDocument;
import cn.superdesk.sync2es.entity.mall.GoodsEntity;
import cn.superdesk.sync2es.service.GoodsService;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Component;

/**
 * @author xc
 * @since 2023/12/21 17:44
 */
@CanalTable(value = "ims_superdesk_shop_goods")
@Component
@Slf4j
@RequiredArgsConstructor
public class GoodsHandler implements EntryHandler<GoodsEntity> {
    private final GoodsService goodsService;


    @Override
    public void insert(GoodsEntity goods) {
        log.info("insert message {}", goods);
        goodsService.save(
                GoodsDocument.builder()
                        .id(goods.getId())
                        .merchid(goods.getMerchid())
                        .type(goods.getType())
                        .status(goods.getStatus())
                        .checked(goods.getChecked())
                        .title(goods.getTitle())
                        .goodssn(goods.getGoodssn())
                        .productsn(goods.getProductsn())
                        .jd_vop_sku(goods.getJd_vop_sku())
                        .build()
        );
    }

    @Override
    public void update(GoodsEntity before, GoodsEntity after) {
        log.info("update before {} ", before);
        log.info("update after {}", after);
        goodsService.save(
                GoodsDocument.builder()
                        .id(after.getId())
                        .merchid(after.getMerchid())
                        .type(after.getType())
                        .status(after.getStatus())
                        .checked(after.getChecked())
                        .title(after.getTitle())
                        .goodssn(after.getGoodssn())
                        .productsn(after.getProductsn())
                        .jd_vop_sku(after.getJd_vop_sku())
                        .build()
        );
    }

    @Override
    public void delete(GoodsEntity goods) {
        log.info("delete message {}", goods);
        if (goods == null || goods.getId() == null) {
            return;
        }
        goodsService.deleteById(goods.getId());
    }
}
